@@ -39,6 +39,9 @@ def run():
     parser = OptionParser(usage=usage)
     parser.add_option('--provider', dest='provider', default='CLOUDFILES_US',
                       help='Provider to use')
+    parser.add_option('--region', dest='region', default=None,
+                      help='Region to use if a Libcloud driver supports \
+                        multiple regions (e.g. ORD for CloudFiles provider)')
     parser.add_option('--username', dest='api_username',
                       help='API username')
     parser.add_option('--key', dest='api_key',
@@ -61,10 +64,10 @@ def run():
                            'exclude')
     parser.add_option('--log-level', dest='log_level', default='INFO',
                       help='Log level')
-    parser.add_option('--delete', dest='delete', action='store_true', 
+    parser.add_option('--delete', dest='delete', action='store_true',
                       help='delete extraneous files from dest containers',
                       default=False)
-   
+
     (options, args) = parser.parse_args()
 
     for option_name, key in REQUIRED_OPTIONS:
@@ -95,6 +98,8 @@ def run():
 
     syncer = FileSyncer(directory=directory,
                         provider_cls=get_driver(provider),
+                        provider=provider,
+                        region=options.region,
                         username=options.api_username,
                         api_key=options.api_key,
                         container_name=options.container_name,
@@ -103,6 +108,6 @@ def run():
                         logger=logger,
                         concurrency=int(options.concurrency))
     if options.restore:
-      syncer.restore()
+        syncer.restore()
     else:
-      syncer.sync(options.delete)
+        syncer.sync(options.delete)
