@@ -45,9 +45,12 @@ from file_syncer.constants import MANIFEST_FILE
 class FileSyncer(object):
     def __init__(self, directory, provider_cls, username, api_key,
                  container_name, cache_path, exclude_patterns,
-                 logger, concurrency=20, retry_limit=3):
+                 logger, provider=None, region=None,
+                 concurrency=20, retry_limit=3):
         self._directory = directory
         self._provider_cls = provider_cls
+        self._provider = provider
+        self._region = region
         self._username = username
         self._api_key = api_key
         self._container_name = container_name
@@ -77,7 +80,8 @@ class FileSyncer(object):
         """
         if not os.path.exists(self._cache_path):
             self._logger.debug('Cache directory doesn\'t exist ' +
-              '(%(directory)s), creating it...', {'directory': self._cache_path})
+                               '(%(directory)s), creating it...',
+                               {'directory': self._cache_path})
             os.makedirs(self._cache_path)
 
     def _setup_container(self):
@@ -87,16 +91,33 @@ class FileSyncer(object):
         driver = self._get_driver_instance()
 
         try:
-            container = driver.get_container(container_name=self._container_name)
+            container = \
+                driver.get_container(container_name=self._container_name)
         except ContainerDoesNotExistError:
             self._logger.debug('Container "%(name)s" doesn\'t exist, ' +
-                    'creating it..', {'name': self._container_name})
-            container = driver.create_container(container_name=self._container_name)
+                               'creating it..', {'name': self._container_name})
+            container = \
+                driver.create_container(container_name=self._container_name)
 
         self._container = container
 
     def _get_driver_instance(self):
-        driver = self._provider_cls(self._username, self._api_key)
+        PROVIDER_HAS_REGION = {
+            'cloudfiles_us': 'ex_force_service_region',
+            'cloudfiles_uk': 'ex_force_service_region'
+        }
+
+        args = (self._username, self._api_key)
+        kwargs = {}
+
+        force_region = PROVIDER_HAS_REGION.get(self._provider, None)
+        if self._region and force_region:
+            kwargs[force_region] = self._region
+
+            self._logger.debug('Forcing region: %(region)s',
+                               {'region': self._region})
+
+        driver = self._provider_cls(*args, **kwargs)
         return driver
 
     def _include_file(self, file_name):
@@ -131,9 +152,11 @@ class FileSyncer(object):
 
             differences = self._get_differences(local_files=local_files,
                                                 remote_files=remote_files)
-            actions = self._calculate_actions(differences=differences, delete=delete)
+            actions = self._calculate_actions(differences=differences,
+                                              delete=delete)
 
-            self._logger.info('To remove: %(to_remove)s, to upload: %(to_upload)s',
+            self._logger.info(('To remove: %(to_remove)s, ',
+                              'to upload: %(to_upload)s'),
                               {'to_remove': len(actions['to_remove']),
                                'to_upload': len(actions['to_upload'])})
 
@@ -207,7 +230,8 @@ class FileSyncer(object):
         driver = self._get_driver_instance()
         name = MANIFEST_FILE
         extra = {'content_type': 'application/json'}
-        container = Container(name=self._container_name, extra=None, driver=driver)
+        container = Container(name=self._container_name, extra=None,
+                              driver=driver)
         iterator = StringIO(data)
         driver.upload_object_via_stream(iterator=iterator, extra=extra,
                                         container=container, object_name=name)
@@ -218,7 +242,8 @@ class FileSyncer(object):
 
         self._logger.debug('Removing object: %(name)s', {'name': name})
 
-        container = Container(name=self._container_name, extra={}, driver=driver)
+        container = Container(name=self._container_name, extra={},
+                              driver=driver)
         obj = Object(name=name, size=None, hash=None, extra=None,
                      meta_data=None, container=container, driver=driver)
 
@@ -229,7 +254,7 @@ class FileSyncer(object):
                                {'name': name, 'error': str(e)})
             if self._should_retry(name):
                 self._logger.info('Retrying object removal "%(name)s"',
-                    {'name': name})
+                                  {'name': name})
                 func = lambda item: self._remove_object(item=item, pool=pool)
                 pool.spawn(func, item)
 
@@ -251,7 +276,8 @@ class FileSyncer(object):
         self._logger.debug('Uploading object: %(name)s', {'name': name})
 
         extra = {'content_type': 'application/octet-stream'}
-        container = Container(name=self._container_name, extra=None, driver=driver)
+        container = Container(name=self._container_name, extra=None,
+                              driver=driver)
 
         try:
             driver.upload_object(file_path=file_path, container=container,
@@ -259,10 +285,10 @@ class FileSyncer(object):
 
         except LibcloudError, e:
             self._logger.error('Failed to upload object "%(name)s": %(error)s',
-                {'name': name, 'error': str(e)})
+                               {'name': name, 'error': str(e)})
             if self._should_retry(name):
                 self._logger.info('Retrying to upload object "%(name)s"',
-                    {'name': name})
+                                  {'name': name})
                 func = lambda item: self._upload_object(item=item, pool=pool)
                 pool.spawn(func, item)
             return
@@ -292,15 +318,16 @@ class FileSyncer(object):
                                                          file_path=file_path)
 
                 if not self._include_file(remote_name):
-                    self._logger.debug('File %(name)s is excluded, skipping it',
+                    self._logger.debug('File %(name)s is excluded skipping it',
                                        {'name': name})
                     continue
 
                 mtime = os.path.getmtime(file_path)
                 md5_hash = None
 
-                item = {'name': name, 'remote_name': remote_name, 'path': file_path,
-                        'last_modified': mtime, 'md5_hash': md5_hash}
+                item = {'name': name, 'remote_name': remote_name,
+                        'path': file_path, 'last_modified': mtime,
+                        'md5_hash': md5_hash}
                 result[remote_name] = item
 
         return result
@@ -325,18 +352,18 @@ class FileSyncer(object):
         try:
             parsed = json.loads(data)
         except Exception, e:
-            raise Exception('Corrupted manifest, failed to parse it: ' + str(e))
+            raise Exception('Corrupted manifest, failed to parse it: ' +
+                            str(e))
 
         return parsed
 
-
     def _download_remote_file(self, name):
         """
         Download a remote file given a name.
         """
 
         self._logger.debug('Downloading object: %(name)s to %(path)s',
-                {'name': name, 'path': self._directory})
+                           {'name': name, 'path': self._directory})
 
         # strip the leading slash if it exists in the object_name
         local_filename = name
@@ -359,7 +386,8 @@ class FileSyncer(object):
             return
 
         driver.download_object(obj=obj, destination_path=filepath,
-                overwrite_existing=True, delete_on_failure=True)
+                               overwrite_existing=True,
+                               delete_on_failure=True)
 
     def _get_differences(self, local_files, remote_files):
         """
